#ProcessorAdvisory.py
'''Functions to process the advisory component.'''

import logging
from typing import List

# gitlab projects
# TODO: Package these projects so they are robust for importing
from AdvisoryBuilder import DataGatherer # created by jws52
from Processor import Processor

from ProcessorUtils import (
        add_filters_to_sublogger,
        endScript,
        open_and_check_config,
        query_past_successes,
        short_name
)


class ProcessorAdvisory(Processor):

    def process_pre_job(self, args):
        return self.process_pre_job_advisory(args)


    def process_in_job(self, jobPath, status, configjson, component) -> object:
        return self.process_in_job_advisory(jobPath, status, configjson, component)


    def process_post_job(self, jobPath, configjson):
        pass


    def __init__(self) -> None:
        super().__init__()
        logger = logging.getLogger('Processor.Advisory')
        add_filters_to_sublogger(logger)

    def process_pre_job_advisory(self,input_args: dict):

        self.logger.info('started process_pre_job_advisory()')

        # check configs can be loaded
        config_fns: List[str] = input_args['config_paths']
        for configFile in config_fns:
            try:
                config_i = open_and_check_config(configFile)
            except:
                self.logger.exception(f"Failure in opening or checking config {configFile}")
                endScript(premature=True)

            # check pre-requisite jobs are complete

            # Which jobs to check are defined by the config. It may include epi
            # and surveys.

            # Note that yesterday's surveys should also have succeeded, but that
            # needs a YesterdayDateString available for the survey part of
            # advisory config to point to the status file.

            dependent_components = config_i['Advisory'].get(
                    'DependentComponents',
                    ['Deposition','Environment'])    

            for dependent_component in dependent_components:

                query_past_successes(input_args, dependent_component)

        return True

    def process_in_job_advisory(self, jobPath, status, config, component):
        '''Generates a word processor file containing some basic survey statistics
        and output figures from deposition, environmental suitability, and
        eventually also the epi model. This template advisory is intended to speed
        up the process of writing advisories. The intended user is a local expert
        who edits the content of the document.
        Uses the gitlab project EWS-advisory-builder.'''

        config_advisory = config[component].copy()

        config_advisory['jobPath'] = jobPath

        # provide top-level arguments to advisory config
        for k,v in config.items():
            if k not in short_name.keys():
                config_advisory[k]=v

        dateString = config['StartString']

        layout = 'tight'

        logging.info(f"Running for scenario {config_advisory}, {dateString}, {layout}")

        report_names = DataGatherer.run_each_subregion(config_advisory, dateString, layout)

        # pass the report filenames to upload to the remote server

        proc_out = {}
        # Output files available for upload
        proc_out['output'] = report_names
        # Processing files available for clearing
        proc_out['clearup'] = None

        return proc_out


if __name__ == '__main__':
    processor = ProcessorAdvisory()
    processor.run_processor("Advisory")